@@ -1,15 +1,12 @@
 package App::FileSummoner::CreateFile;
 BEGIN {
-  $App::FileSummoner::CreateFile::VERSION = '0.004';
+  $App::FileSummoner::CreateFile::VERSION = '0.005';
 }
 
-use 5.006;
-use strict;
-use warnings;
-
 use Moose;
 use Template;
 use File::Spec;
+use File::Basename qw/ fileparse /;
 
 use App::FileSummoner::SkeletonDirsFinder;
 use App::FileSummoner::Register qw(chooseSkeleton registerSkeleton);
@@ -55,6 +52,7 @@ sub summonFileToStdout {
 sub summonFileTo {
     my ($self, $fileName, $target) = @_;
 
+    $fileName = File::Spec->rel2abs( $fileName );
     my @skeletonDirs =
       App::FileSummoner::SkeletonDirsFinder->new->findForFile( $fileName );
 
@@ -63,14 +61,31 @@ sub summonFileTo {
     my $template = Template->new(
         INCLUDE_PATH => [@skeletonDirs],
         TRIM         => 1,
-        INTERPOLATE  => 1,
     );
 
-    my $skeleton = chooseSkeleton( File::Spec->rel2abs( $fileName ) )
+    my $skeleton = chooseSkeleton( $fileName )
       || die "Couldn't find suitable skeleton for " . $fileName;
     print STDERR "Skeleton: " . $skeleton . "\n";
-    $template->process( $skeleton, {}, $target )
-      || die $template->error . "\n";
+    $template->process( $skeleton, $self->templateVarsForFile($fileName),
+        $target )
+        || die $template->error . "\n";
+}
+
+=head2 templateVarsForFile
+
+Return template variables for given filename.
+
+  {
+      name => 'file name without extension',
+  }
+
+=cut
+
+sub templateVarsForFile {
+    my ($self, $fileName) = @_;
+
+    my ($name) = fileparse($fileName, qr/\.[^.]*/);
+    return { name => $name };
 }
 
 =head2 loadRules
